@@ -1,5 +1,5 @@
 """Handle MySensors messages."""
-from typing import Dict, List
+from __future__ import annotations
 
 from mysensors import Message
 
@@ -8,14 +8,7 @@ from homeassistant.helpers.dispatcher import async_dispatcher_send
 from homeassistant.helpers.typing import HomeAssistantType
 from homeassistant.util import decorator
 
-from .const import (
-    CHILD_CALLBACK,
-    DOMAIN,
-    MYSENSORS_GATEWAY_READY,
-    NODE_CALLBACK,
-    DevId,
-    GatewayId,
-)
+from .const import CHILD_CALLBACK, NODE_CALLBACK, DevId, GatewayId
 from .device import get_mysensors_devices
 from .helpers import discover_mysensors_platform, validate_set_msg
 
@@ -75,32 +68,18 @@ async def handle_sketch_version(
     _handle_node_update(hass, gateway_id, msg)
 
 
-@HANDLERS.register("I_GATEWAY_READY")
-async def handle_gateway_ready(
-    hass: HomeAssistantType, gateway_id: GatewayId, msg: Message
-) -> None:
-    """Handle an internal gateway ready message.
-
-    Set asyncio future result if gateway is ready.
-    """
-    gateway_ready = hass.data[DOMAIN].get(MYSENSORS_GATEWAY_READY.format(gateway_id))
-    if gateway_ready is None or gateway_ready.cancelled():
-        return
-    gateway_ready.set_result(True)
-
-
 @callback
 def _handle_child_update(
-    hass: HomeAssistantType, gateway_id: GatewayId, validated: Dict[str, List[DevId]]
+    hass: HomeAssistantType, gateway_id: GatewayId, validated: dict[str, list[DevId]]
 ):
     """Handle a child update."""
-    signals: List[str] = []
+    signals: list[str] = []
 
     # Update all platforms for the device via dispatcher.
     # Add/update entity for validated children.
     for platform, dev_ids in validated.items():
         devices = get_mysensors_devices(hass, platform)
-        new_dev_ids: List[DevId] = []
+        new_dev_ids: list[DevId] = []
         for dev_id in dev_ids:
             if dev_id in devices:
                 signals.append(CHILD_CALLBACK.format(*dev_id))
